package URI::Fast::IRI;
# ABSTRACT: IRI support for URI::Fast
$URI::Fast::IRI::XS_VERSION = $URI::Fast::IRI::VERSION = '0.35_3'; # TRIAL

$URI::Fast::IRI::VERSION = '0.353';our @ISA = qw(URI::Fast);


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

URI::Fast::IRI - IRI support for URI::Fast

=head1 VERSION

version 0.35_3

=head1 DESCRIPTION

See L<URI::Fast/iri>.

=head1 AUTHOR

Jeff Ober <sysread@fastmail.fm>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Jeff Ober.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
